module.exports = defineTest({
	description: 'supports import.meta.resolve'
});
